@@ -54,13 +54,13 @@ setGeneric("MonthPubmed",function(object) standardGeneric("MonthPubmed"))
 setGeneric("DayPubmed",function(object) standardGeneric("DayPubmed"))                                  
 setGeneric("HourPubmed",function(object) standardGeneric("HourPubmed"))                                
 setGeneric("MinutePubmed",function(object) standardGeneric("MinutePubmed"))                         
-setGeneric("Author",function(object) standardGeneric("Author"))                            
+setGeneric("Author",  function(object) standardGeneric("Author"))                            
 setGeneric("ISSN",function(object) standardGeneric("ISSN"))                                
 setGeneric("Title",function(object) standardGeneric("Title"))                              
 setGeneric("ArticleTitle",function(object) standardGeneric("ArticleTitle"))                
 setGeneric("ELocationID",function(object) standardGeneric("ELocationID"))                  
 setGeneric("AbstractText",function(object) standardGeneric("AbstractText"))                
-setGeneric("Affiliation",function(object) standardGeneric("Affiliation"))                  
+setGeneric("Affiliation", function(object) standardGeneric("Affiliation"))                  
 setGeneric("Language",function(object) standardGeneric("Language"))                        
 setGeneric("PublicationType",function(object) standardGeneric("PublicationType"))          
 setGeneric("MedlineTA",function(object) standardGeneric("MedlineTA"))                      
@@ -75,12 +75,8 @@ setGeneric("ISOAbbreviation",function(object) standardGeneric("ISOAbbreviation")
 setGeneric("MedlinePgn",function(object) standardGeneric("MedlinePgn"))                    
 setGeneric("CopyrightInformation",function(object) standardGeneric("CopyrightInformation"))
 setGeneric("Country",function(object) standardGeneric("Country"))                          
-setGeneric("GrantID",function(object) standardGeneric("GrantID"))                          
-setGeneric("Acronym",function(object) standardGeneric("Acronym"))                          
-setGeneric("Agency",function(object) standardGeneric("Agency"))                            
-setGeneric("RegistryNumber",function(object) standardGeneric("RegistryNumber"))            
-setGeneric("RefSource",function(object) standardGeneric("RefSource"))                      
-setGeneric("CollectiveName",function(object) standardGeneric("CollectiveName"))
+setGeneric("GrantID", function(object) standardGeneric("GrantID"))              
 setGeneric("COIStatement",function(object) standardGeneric("COIStatement"))
-setGeneric("Mesh",function(object) standardGeneric("Mesh"))
-setGeneric("Cited", function(object) standardGeneric("Cited"))
+setGeneric("Mesh", function(object) standardGeneric("Mesh"))
+setGeneric("Keywords",  function(object) standardGeneric("Keywords"))
+setGeneric("Citations",  function(object) standardGeneric("Citations"))
